library(Hmisc)


q = c(
  'Ellen walked into her office. Her computer seemed to have been stolen.',
  'Greg bought a dozen eggs.  The egg was broken.',  
  'Kim started her computer. The steering wheel was cold.',
  'Hank closed the window. The bee was buzzing just outside it.',
  'At the coffee shop, Joan was reading near the back. The table was a bit tippy.',
  'At the coffee shop, Joan looked around for a place to sit. The table was a bit tippy.',
  'Sam was browsing around the campus bicycle shop. The front wheel was misaligned.',
  'Sam brought his bicycle to the campus bicycle shop. The front wheel was misaligned.'
  )


a = read.csv('results-a.csv')
b = read.csv('results-b.csv')


## Combine the items that were the same for both:
combo = rbind(a[,c(1, 2, 4, 5)], b[,c(1, 2, 4, 5)])

## Exxtract target columns:
seated = a[ , 3]
browse = a[ , 6]
look = b[ , 3]
bring = b[ , 6]

## Vector of targets:
targets = c(seated, browse, look, bring)

CalculateError = function(mean, std, n) {
  err = qnorm(0.975)*(std/sqrt(n))
  return(err)
}

CalculateCIs = function(means, stds, sizes) {
  errs = CalculateError(means, stds, sizes)
  return(list(left=means-errs, right=means+errs))  
}

means = apply(combo, 2, mean)
means = c(means, mean(seated), mean(browse), mean(look), mean(bring))

stds = apply(combo, 2, sd)
stds = c(stds, sd(seated), sd(browse), sd(look), sd(bring))

lengths = c(length(seated), length(look), length(browse), length(bring))
lengths = c(lengths, rep(nrow(combo), 4))

leftright = CalculateCIs(means, stds, lengths)

left = leftright[['left']]
right = leftright[['right']]

par(mar=c(6, 32, 1, 1), oma=c(0,0,4,6))
plt = barplot(means,names.arg=q,
  horiz=TRUE, col='black', angle=c(0, 0, 0, 0, 45, 45, 90, 90), density=c(0,0,0,0, 3, 3, 3, 3),
  las=1, width=c(1,1,1,1,1,1,1,1)-0.9, ylim=c(0,1), xlim=c(0, 5.5),
  axes=F, cex.names=0.9)


axis(1, at=round(c(0,means[1:4]), 2), las=3)
axis(3, at=round(c(0,means[5:8]), 2), las=3)

for (i in 1:length(lengths)) { lengths[i] = paste('N = ', lengths[i]) }

segments(left, plt, right, plt, col='black', lwd=4)

mtext(lengths, at=rev(plt), side=4, outer=F, las=1, line=1)
mtext('Mean response with 95% confidence interval', side=1, line=4, cex=1.5)
mtext('  Ling 130a definites survey results - Winter 2019', side=3, line=1, cex=1.7, outer=TRUE, adj=0)

##legend(5.5, 1, legend='95% conf. intervals', xjust=1, yjust=1, lwd=4, col='black')

